@@ -6,6 +6,7 @@
 #' @param B Complete dataset of independent variables (IV) in matrix form.
 #' @param y Dependent variable (DV).
 #' @param order Controls the number of the \code{VN.reg}.  Defaults to \code{order=1}.
+#' @param n.best Sets the number of closest regression points to use in kernel weighting.  Defaults to number of independent variables.
 #' @param type Controls the partitioning in \code{VN.reg}.  Defaults to \code{type="XONLY"} for IV based partitioning.   \code{type=NULL} for both IV and DV partitioning.
 #' @param point.est Generates a fitted value of \code{y} for a vector or matrix of IV coordinates.
 #' @param plot Generates a 3d scatter plot with regression points using \link{plot3d}
@@ -21,11 +22,11 @@
 #' VN.M.reg(B,y)
 #' @export
 
-VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residual.plot=TRUE){
+VN.M.reg <- function (B,y,order=1,n.best=NULL,type="XONLY",point.est=NULL, plot=FALSE,residual.plot=TRUE){
 
   n=ncol(B)
+  if(is.null(n.best)){n.best=n}else{n.best=n.best}
   np=nrow(point.est)
-  overall.matrix = cbind(B,y)
 
   findInterval2Vec = Vectorize(findInterval2,vectorize.args="x")
   ### For Multiple regressions
@@ -60,7 +61,7 @@ VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residu
   intervals = list()
 
   for(j in 1:n){
-    intervals[[j]]=findInterval2Vec(B[,j],reg.points.matrix[,j])
+    intervals[[j]]=findInterval2Vec(B[,j],sort(unique(reg.points.matrix[,j])))
   }
 
   intervals = matrix(unlist(intervals),nrow = length(y),ncol = n)
@@ -69,6 +70,8 @@ VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residu
   ## Create unique identifier of each observation's interval
   intervals = apply(intervals, 1 , paste , collapse = "" )
   y.identifier = cbind(as.numeric(y),as.numeric(intervals))     ## Match y to unique identifier
+  overall.matrix = cbind(B,y,y.identifier[,2])
+
   y.hat.matrix =  data.frame(matrix(ncol = 2))
   y.hat=numeric()
 
@@ -77,6 +80,7 @@ VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residu
   }
 
 
+
   y.identifier = cbind(y.identifier,y.hat)
 
   y.identifier = y.identifier[order(y.identifier[,2]),]
@@ -85,71 +89,59 @@ VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residu
 
   fitted.matrix = cbind(B,y.hat)
 
-  ### Matrix is means of intervals, thus regression points.
-  mult.reg.points.matrix = as.data.frame(matrix(ncol=n))
+  unique.identifiers=unique(overall.matrix[,(n+2)])
 
-  # X1 and X2 are for plot3d
-  combo.x1 = numeric()
-  combo.x2 = numeric()
-  for(j in 1:n){
-    for(i in 1:(reg.length-1)){
-      mult.reg.points.matrix[1,j]= mean(reg.points.matrix[1,j])
-      mult.reg.points.matrix[(i+1),j]= mean(reg.points.matrix[(i:(i+1)),j])
-      combo.x1[i]= mean(reg.points.matrix[(i:(i+1)),1])
-      combo.x2[i]= mean(reg.points.matrix[(i:(i+1)),2])
-      mult.reg.points.matrix[reg.length,j]= mean(reg.points.matrix[reg.length,j])
-    }
+  ### GET REGRESSION POINTS USING Y.IDENTIFIER!!!
+  REGRESSION.POINT.MATRIX = data.frame(matrix(ncol=n+2))
+  for(j in 1:length(unique.identifiers)){
+    for(i in 1:n){
+      REGRESSION.POINT.MATRIX[j,i]=mean(c(overall.matrix[overall.matrix[,(n+2)]==unique.identifiers[j],i]))
+      REGRESSION.POINT.MATRIX[j,(n+1)]=mean(c(overall.matrix[overall.matrix[,(n+2)]==unique.identifiers[j],(n+1)]))
+      REGRESSION.POINT.MATRIX[j,(n+2)]=mean(c(overall.matrix[overall.matrix[,(n+2)]==unique.identifiers[j],(n+2)]))
+      }
   }
-
-  ### Expand the points to see all intervals
-  e.g.mult.reg.points.matrix=expand.grid(mult.reg.points.matrix)
-
-  ### Find y for unique intervals in Multiple Regression Points Matrix m.r.p.
-  y.m.r.p.identifier=list()
-  for(j in 1:n){
-    y.m.r.p.identifier[[j]]=findInterval2Vec(e.g.mult.reg.points.matrix[,j],reg.points.matrix[,j])
-  }
-
-  y.m.r.p.identifier = matrix(unlist(y.m.r.p.identifier),nrow =length(e.g.mult.reg.points.matrix[,1]),ncol = n)
-  y.m.r.p.identifier = apply(y.m.r.p.identifier, 1 , paste , collapse = "" )
-  y.m.r.p.identifier = as.numeric(y.m.r.p.identifier)
-
-  e.g.mult.reg.points.matrix = cbind(e.g.mult.reg.points.matrix, y.m.r.p.identifier)
-
-
-  y.m.r.p.identifier = e.g.mult.reg.points.matrix[e.g.mult.reg.points.matrix[,(n+1)]%in%y.identifier[,2],(n+1)]
-
-  e.g.mult.reg.points.matrix = e.g.mult.reg.points.matrix[e.g.mult.reg.points.matrix[,(n+1)]%in%y.identifier[,2],-(n+1)]
-
-  Conditional.y.means = numeric()
-
-  for(i in 1:length(y.m.r.p.identifier)){
-    Conditional.y.means[i] = mean(y.identifier[,1][y.identifier[,2]==y.m.r.p.identifier[i]])
-  }
-
-  REGRESSION.POINT.MATRIX=cbind(e.g.mult.reg.points.matrix, Conditional.y.means, y.m.r.p.identifier)
-
+  REGRESSION.POINT.MATRIX=na.omit(REGRESSION.POINT.MATRIX)
+  
 
   ### DISTANCES
   ## Calculate distance from each point in REGRESSION.POINT.MATRIX
   if(!is.null(point.est)){
-  distance<- function(dist.est){
+    distance<- function(dist.est){
       distances=data.frame(nrow=length(REGRESSION.POINT.MATRIX[,1]),ncol=n)
       row.sums=numeric()
 
       for(i in 1:length(REGRESSION.POINT.MATRIX[,1])){
         for(j in 1:n){
-        distances[i,j]=abs(dist.est[j]-REGRESSION.POINT.MATRIX[i,j])
+          distances[i,j]=abs(dist.est[j]-REGRESSION.POINT.MATRIX[i,j])
         }
+
         distances[i,][distances[i,]==0]<- 1e-10
-        row.sums[i] = prod(distances[i,]^2)
-
+        row.sums[i] = sum(distances[i,]^2)
       }
 
-
       total.row.sums = sum(1/row.sums)
 
       weights = (1/row.sums)/total.row.sums
+      
+      which_nth_highest <- function(xx, n)
+      {
+        ux <- unique(xx)
+        nux <- length(ux)
+        which(xx == sort(ux, partial = nux - n + 1)[nux - n + 1])
+      }
+
+      highest=numeric()
+      for(k in 1:n.best){
+          highest[k]=which_nth_highest(weights,k)
+          }
+
+
+      weights[-c(highest)]<-0
+      weights.sum=sum(weights)
+
+      for(l in 1:length(weights)){
+        weights[l]=weights[l]/weights.sum
+      }
 
       single.estimate = sum(weights*REGRESSION.POINT.MATRIX[,(n+1)])
       return(single.estimate)
@@ -168,7 +160,7 @@ VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residu
         predict.fit.iter[j] = distance(dist.est = point.est[j,])
       }
       predict.fit=predict.fit.iter
-      }
+    }
 
   }
 
@@ -178,11 +170,7 @@ VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residu
 
 
   if(plot==TRUE&&n==2){
-    # For 3d plot which can only have 2 RHS variables
-    max.x1 = max(overall.matrix[,1])
-    max.x2 = max(overall.matrix[,2])
-    REGRESSION.POINT.MATRIX=rbind(REGRESSION.POINT.MATRIX,c(max.x1,overall.matrix[,2][overall.matrix[,1]==max.x1],overall.matrix[,(n+1)][overall.matrix[,1]==max.x1]))
-    REGRESSION.POINT.MATRIX=rbind(REGRESSION.POINT.MATRIX,c(overall.matrix[,1][overall.matrix[,2]==max.x2],max.x2,overall.matrix[,(n+1)][overall.matrix[,2]==max.x2]))
+
     REGRESSION.POINT.MATRIX=REGRESSION.POINT.MATRIX[order(REGRESSION.POINT.MATRIX[,(n+1)]),]
 
     plot3d(x=B[,1],y=B[,2],z=y,box=F,size = 3,col='steelblue',xlab="X1", ylab="X2", zlab="Y" )
@@ -197,6 +185,8 @@ VN.M.reg <- function (B,y,order=1,type="XONLY",point.est=NULL, plot=FALSE,residu
       }
     }
 
+    # movie3d(spin3d(axis = c(.75, .75, .75)), duration = 20,dir = getwd(),convert=FALSE)
+
   }
 
   if(residual.plot==TRUE){
